pub struct SamEncoder<B: Backend> { /* private fields */ }Expand description
SAM vision encoder for the DeepSeek-OCR DeepEncoder architecture.
Implements the complete SAM encoding pipeline:
- Patch embedding: Image → patches
- Position embedding: Add learned position encodings
- Transformer blocks: Window/global attention processing
- Neck: Project to output channels
- Compression: 16× spatial reduction via convolutional layers
Compression Pipeline
For a 1024×1024 image with 16×16 patches:
- Input:
[B, 3, 1024, 1024] - After patch embed:
[B, 768, 64, 64](1024/16 = 64) - After transformers:
[B, 768, 64, 64] - After neck:
[B, 256, 64, 64] - After comp1:
[B, 512, 32, 32](stride=2) - After comp2:
[B, 1024, 16, 16](stride=2) - Result: 16× compression (64² → 16² tokens)
Implementations
Sourceimpl<B: Backend> SamEncoder<B>
impl<B: Backend> SamEncoder<B>
Sourcepub fn forward(&self, x: Tensor<B, 4>) -> Tensor<B, 4>
pub fn forward(&self, x: Tensor<B, 4>) -> Tensor<B, 4>
Encodes an image into compressed vision features.
Arguments
x- Input image tensor
Shape
- Input:
[B, 3, H, W] - Output:
[B, 1024, H/P/4, W/P/4]where P is patch_size
For default settings (patch_size=16, 16× compression):
- 1024×1024 image →
[B, 1024, 16, 16](256 tokens) - 512×512 image →
[B, 1024, 8, 8](64 tokens)
Example
ⓘ
let image = Tensor::zeros(, &device);[1]
let features = encoder.forward(image);
// Shape: = 256 vision tokens[2][1]Trait Implementations
Sourceimpl<B> AutodiffModule<B> for SamEncoder<B>
impl<B> AutodiffModule<B> for SamEncoder<B>
Sourcetype InnerModule = SamEncoder<<B as AutodiffBackend>::InnerBackend>
type InnerModule = SamEncoder<<B as AutodiffBackend>::InnerBackend>
Inner module without auto-differentiation.
Sourcefn valid(&self) -> Self::InnerModule
fn valid(&self) -> Self::InnerModule
Get the same module, but on the inner backend without auto-differentiation.
Sourceimpl<B: Backend> Clone for SamEncoder<B>
impl<B: Backend> Clone for SamEncoder<B>
Sourceimpl<B: Backend> Display for SamEncoder<B>
impl<B: Backend> Display for SamEncoder<B>
Sourceimpl<B: Backend> Module<B> for SamEncoder<B>
impl<B: Backend> Module<B> for SamEncoder<B>
Sourcetype Record = SamEncoderRecord<B>
type Record = SamEncoderRecord<B>
Type to save and load the module.
Sourcefn load_record(self, record: Self::Record) -> Self
fn load_record(self, record: Self::Record) -> Self
Load the module state from a record.
Sourcefn into_record(self) -> Self::Record
fn into_record(self) -> Self::Record
Convert the module into a record containing the state.
Sourcefn num_params(&self) -> usize
fn num_params(&self) -> usize
Get the number of parameters the module has, including all of its sub-modules.
Sourcefn visit<Visitor: ModuleVisitor<B>>(&self, visitor: &mut Visitor)
fn visit<Visitor: ModuleVisitor<B>>(&self, visitor: &mut Visitor)
Visit each tensor parameter in the module with a visitor.
Sourcefn map<Mapper: ModuleMapper<B>>(self, mapper: &mut Mapper) -> Self
fn map<Mapper: ModuleMapper<B>>(self, mapper: &mut Mapper) -> Self
Map each tensor parameter in the module with a mapper.
Sourcefn collect_devices(&self, devices: Devices<B>) -> Devices<B>
fn collect_devices(&self, devices: Devices<B>) -> Devices<B>
Return all the devices found in the underneath module tree added to the given vector
without duplicates.
Sourcefn to_device(self, device: &B::Device) -> Self
fn to_device(self, device: &B::Device) -> Self
Move the module and all of its sub-modules to the given device. Read more
Sourcefn fork(self, device: &B::Device) -> Self
fn fork(self, device: &B::Device) -> Self
Fork the module and all of its sub-modules to the given device. Read more
Sourcefn devices(&self) -> Vec<<B as Backend>::Device>
fn devices(&self) -> Vec<<B as Backend>::Device>
Return all the devices found in the underneath module tree without duplicates.
Sourcefn save_file<FR, PB>(
self,
file_path: PB,
recorder: &FR,
) -> Result<(), RecorderError>
fn save_file<FR, PB>( self, file_path: PB, recorder: &FR, ) -> Result<(), RecorderError>
Save the module to a file using the provided file recorder. Read more
Sourcefn load_file<FR, PB>(
self,
file_path: PB,
recorder: &FR,
device: &<B as Backend>::Device,
) -> Result<Self, RecorderError>
fn load_file<FR, PB>( self, file_path: PB, recorder: &FR, device: &<B as Backend>::Device, ) -> Result<Self, RecorderError>
Load the module from a file using the provided file recorder. Read more
Sourcefn quantize_weights(self, quantizer: &mut Quantizer) -> Self
fn quantize_weights(self, quantizer: &mut Quantizer) -> Self
Quantize the weights of the module.
Sourceimpl<B: Backend> ModuleDisplay for SamEncoder<B>
impl<B: Backend> ModuleDisplay for SamEncoder<B>
Sourcefn format(&self, passed_settings: DisplaySettings) -> String
fn format(&self, passed_settings: DisplaySettings) -> String
Formats the module with provided display settings. Read more
Sourcefn custom_settings(&self) -> Option<DisplaySettings>
fn custom_settings(&self) -> Option<DisplaySettings>
Custom display settings for the module. Read more